// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___CXX03___THREAD_SUPPORT_EXTERNAL_H
#define _LIBCPP___CXX03___THREAD_SUPPORT_EXTERNAL_H

#include <__cxx03/__config>

#ifndef _LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER
#  pragma GCC system_header
#endif

#include <__cxx03/__external_threading>

#endif // _LIBCPP___CXX03___THREAD_SUPPORT_EXTERNAL_H
